@@ -9,7 +9,14 @@ TINYIPA_REQUIRE_BIOSDEVNAME=${TINYIPA_REQUIRE_BIOSDEVNAME:-false}
 TINYIPA_REQUIRE_IPMITOOL=${TINYIPA_REQUIRE_IPMITOOL:-true}
 IRONIC_LIB_SOURCE=${IRONIC_LIB_SOURCE:-}
 USE_PYTHON3=${USE_PYTHON3:-True}
-TC_RELEASE="9.x"
+TC_RELEASE="10.x"
+
+TGT_RELEASE="v1.0.79"
+QEMU_RELEASE="v3.1.1"
+LSHW_RELEASE="B.02.18"
+
+BIOSDEVNAME_RELEASE="0.7.2"
+IPMITOOL_RELASE="1_8_18"
 
 # PYTHON_EXTRA_SOURCES_DIR_LIST is a csv list of python package dirs to include
 PYTHON_EXTRA_SOURCES_DIR_LIST=${PYTHON_EXTRA_SOURCES_DIR_LIST:-}
@@ -61,14 +68,14 @@ mkdir "$BUILDDIR"
 sudo sh -c "echo $TINYCORE_MIRROR_URL > $BUILDDIR/opt/tcemirror"
 
 # Download TGT, Qemu-utils, Biosdevname and IPMItool source
-clone_single_branch "https://github.com/fujita/tgt.git" "${BUILDDIR}/tmp/tgt" "v1.0.79"
-clone_single_branch "https://github.com/qemu/qemu.git" "${BUILDDIR}/tmp/qemu" "v3.1.1"
-clone_single_branch "https://github.com/lyonel/lshw.git" "${BUILDDIR}/tmp/lshw" "B.02.18"
+clone_single_branch "https://github.com/fujita/tgt.git" "${BUILDDIR}/tmp/tgt" "$TGT_RELEASE"
+clone_single_branch "https://github.com/qemu/qemu.git" "${BUILDDIR}/tmp/qemu" "$QEMU_RELEASE"
+clone_single_branch "https://github.com/lyonel/lshw.git" "${BUILDDIR}/tmp/lshw" "$LSHW_RELEASE"
 if $TINYIPA_REQUIRE_BIOSDEVNAME; then
-    wget -N -O - https://linux.dell.com/biosdevname/biosdevname-0.7.2/biosdevname-0.7.2.tar.gz | tar -xz -C "${BUILDDIR}/tmp" -f -
+    wget -N -O - https://linux.dell.com/biosdevname/biosdevname-${BIOSDEVNAME_RELEASE}/biosdevname-${BIOSDEVNAME_RELEASE}.tar.gz | tar -xz -C "${BUILDDIR}/tmp" -f -
 fi
 if $TINYIPA_REQUIRE_IPMITOOL; then
-    wget -N -O - https://github.com/ipmitool/ipmitool/archive/IPMITOOL_1_8_18.tar.gz | tar -xz -C "${BUILDDIR}/tmp" -f -
+    wget -N -O - https://github.com/ipmitool/ipmitool/archive/IPMITOOL_${IPMITOOL_RELASE}.tar.gz | tar -xz -C "${BUILDDIR}/tmp" -f -
 fi
 
 # Create directory for python local mirror
@@ -79,14 +86,20 @@ IPA_SOURCE_DIR=${IPA_SOURCE_DIR:-/opt/stack/ironic-python-agent}
 cd $IPA_SOURCE_DIR
 rm -rf *.egg-info
 pwd
-python setup.py sdist --dist-dir "$BUILDDIR/tmp/localpip" --quiet
+
+PYTHON_COMMAND="python"
+if [[ $USE_PYTHON3 == "True" ]]; then
+    PYTHON_COMMAND="python3"
+fi
+$PYTHON_COMMAND setup.py sdist --dist-dir "$BUILDDIR/tmp/localpip" --quiet
+
 ls $BUILDDIR/tmp/localpip || true
 cp requirements.txt $BUILDDIR/tmp/ipa-requirements.txt
 
 if [ -n "$IRONIC_LIB_SOURCE" ]; then
     pushd $IRONIC_LIB_SOURCE
     rm -rf *.egg-info
-    python setup.py sdist --dist-dir "$BUILDDIR/tmp/localpip" --quiet
+    $PYTHON_COMMAND setup.py sdist --dist-dir "$BUILDDIR/tmp/localpip" --quiet
     cp requirements.txt $BUILDDIR/tmp/ironic-lib-requirements.txt
     popd
 fi
@@ -94,10 +107,10 @@ fi
 if [ -n "$PYTHON_EXTRA_SOURCES_DIR_LIST" ]; then
     IFS="," read -ra PKGDIRS <<< "$PYTHON_EXTRA_SOURCES_DIR_LIST"
     for PKGDIR in "${PKGDIRS[@]}"; do
-        PKG=$(cd "$PKGDIR" ; python setup.py --name)
+        PKG=$(cd "$PKGDIR" ; $PYTHON_COMMAND setup.py --name)
         pushd "$PKGDIR"
         rm -rf *.egg-info
-        python setup.py sdist --dist-dir "$BUILDDIR/tmp/localpip" --quiet
+        $PYTHON_COMMAND setup.py sdist --dist-dir "$BUILDDIR/tmp/localpip" --quiet
         if [[ -r requirements.txt ]]; then
             cp requirements.txt $BUILDDIR/tmp/${PKG}-requirements.txt
         fi
@@ -147,6 +160,8 @@ $CHROOT_CMD chmod a+rwx /etc/sysconfig/tcuser
 mkdir $BUILDDIR/tmp/overides
 cp $WORKDIR/build_files/fakeuname $BUILDDIR/tmp/overides/uname
 
+sudo cp $WORKDIR/build_files/ntpdate $BUILDDIR/bin/ntpdate
+
 PY_REQS="buildreqs_python2.lst"
 if [[ $USE_PYTHON3 == "True" ]]; then
     PY_REQS="buildreqs_python3.lst"
@@ -176,7 +191,7 @@ fi
 if [ -n "$PYTHON_EXTRA_SOURCES_DIR_LIST" ]; then
     IFS="," read -ra PKGDIRS <<< "$PYTHON_EXTRA_SOURCES_DIR_LIST"
     for PKGDIR in "${PKGDIRS[@]}"; do
-        PKG=$(cd "$PKGDIR" ; python setup.py --name)
+        PKG=$(cd "$PKGDIR" ; $PYTHON_COMMAND setup.py --name)
         if [[ -r $BUILDDIR/tmp/${PKG}-requirements.txt ]]; then
             $CHROOT_CMD ${PIP_COMMAND} wheel -c /tmp/upper-constraints.txt --wheel-dir /tmp/wheels -r /tmp/${PKG}-requirements.txt
         fi
